@@ -5,6 +5,7 @@
 # here and the like.
 
 use strict;
+use warnings;
 
 use File::Spec;
 
@@ -13,17 +14,22 @@ my $test_dsn  = $ENV{DBI_DSN}  || "DBI:CSV:f_dir=$test_dir";
 my $test_user = $ENV{DBI_USER} || "";
 my $test_pass = $ENV{DBI_PASS} || "";
 
+# Start each test clean
+unlink glob "$test_dir/*";
+
 sub COL_NULLABLE () { 1 }
 sub COL_KEY      () { 2 }
 
 my %v;
-eval "require $_; \$v{'$_'} = \$_::VERSION;" for qw(
-    DBI SQL::Statement Text::CSV_XS DBD::CSV );
+{   my @req = qw( DBI SQL::Statement Text::CSV_XS DBD::CSV );
+    my $req = join ";\n" => map { qq{require $_;\n\$v{"$_"} = $_->VERSION ()} } @req;
+    eval $req;
 
-if ($@) {
-    my @missing = grep { exists $v{$_} } qw( DBI SQL CSV );
-    print STDERR "\n\nYOU ARE MISSING REQUIRED MODULES: [ @missing ]\n\n";
-    exit 0;
+    if ($@) {
+	my @missing = grep { !exists $v{$_} } @req;
+	print STDERR "\n\nYOU ARE MISSING REQUIRED MODULES: [ @missing ]\n\n";
+	exit 0;
+	}
     }
 
 sub AnsiTypeToDb
@@ -158,7 +164,7 @@ sub DbDir
 {
     @_ and $test_dir = File::Spec->catdir (File::Spec->curdir (), shift);
     $test_dir;
-    } # DbFile
+    } # DbDir
 
 sub DbFile
 {
